@@ -45,7 +45,7 @@
 #include <setjmp.h>
 #include <jpeglib.h>
 #include <jerror.h>
-#include <transupp.h>
+#include "transupp.h"
 #include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <glib/gi18n.h>
@@ -158,6 +158,9 @@ init_transform_info (EogImage *image, jpeg_transform_info *info)
 
 	info->transform = trans_code;
 	info->trim      = FALSE;
+#if JPEG_LIB_VERSION >= 80
+	info->crop = FALSE;
+#endif
 	info->force_grayscale = FALSE;
 
 	g_object_unref (composition);
@@ -378,6 +381,7 @@ _save_any_as_jpeg (EogImage *image, const char *file, EogImageSaveInfo *source,
 			     GDK_PIXBUF_ERROR,
 			     GDK_PIXBUF_ERROR_INSUFFICIENT_MEMORY,
 			     _("Couldn't allocate memory for loading JPEG file"));
+		fclose (outfile);
 		return FALSE;
 	}
 
@@ -398,6 +402,7 @@ _save_any_as_jpeg (EogImage *image, const char *file, EogImageSaveInfo *source,
 
 	/* error exit routine */
 	if (sigsetjmp (jerr.setjmp_buffer, 1)) {
+		g_free (buf);
 		fclose (outfile);
 		jpeg_destroy_compress (&cinfo);
 		return FALSE;
